@@ -59,7 +59,7 @@ namespace gdestraier {
                                  char const* mime_type) const
       {
         doc->create();
-        doc->set_attr(ESTDATTRTYPE, mime_type);
+        doc->set_attr(ESTDATTRTYPE, (mime_type? mime_type : "text/html"));
 
         if (info->size == 0) return true;
 
