@@ -103,7 +103,6 @@ namespace gdestraier {
                                    ((i->document_encoding_ == 0)? "Auto" : i->document_encoding_->id_));
           index_elm->set_attribute("filetype", i->filetype_->get_name());
           index_elm->set_attribute("language", i->language_);
-          index_elm->set_attribute("filesystem_encoding", i->filesystem_encoding_->id_);
           index_elm->set_attribute("use_Ngram_for_all_languages",
                                    i->use_Ngram_for_all_languages_? "yes" : "no");
           index_elm->set_attribute("include_document_title_to_body",
@@ -288,7 +287,6 @@ namespace gdestraier {
               current_index->document_encoding_ = 0;
               current_index->filetype_ = filetypes_manager::instance().find("Auto");
               current_index->language_ = "en";
-              current_index->filesystem_encoding_ = encoding::find("Default");
               current_index->use_Ngram_for_all_languages_ = false;
               current_index->is_enable_quick_build_ = false;
 
@@ -317,8 +315,6 @@ namespace gdestraier {
                   current_index->document_encoding_ = (i->value == "Auto")? 0 : encoding::find(i->value.c_str());
                 } else if (i->name == "language")
                   current_index->language_ = i->value;
-                else if (i->name == "filesystem_encoding")
-                  current_index->filesystem_encoding_ = encoding::find(i->value.c_str());
                 else if (i->name == "use_Ngram_for_all_languages")
                   current_index->use_Ngram_for_all_languages_ = (i->value == "yes")? true : false;
                 else if (i->name == "include_document_title_to_body")
